/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2003 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.conf.impl;

import java.util.*;
import com.silverwrist.dynamo.except.*;
import com.silverwrist.dynamo.iface.*;
import com.silverwrist.venice.iface.*;
import com.silverwrist.venice.conf.iface.*;
import com.silverwrist.venice.conf.obj.*;

public class ConferenceManager implements ConferenceAccessObject
{
  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private DynamicImplConferenceAccess m_dobj;
  private UseCount m_uc;
  private ConferenceManagerOps m_ops;

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public ConferenceManager(UseCount uc, DBConnectionPool pool) throws ModuleException
  {
    try
    { // initialize everything
      m_dobj = new DynamicImplConferenceAccess(this);
      m_uc = uc;
      uc.incrementUseCount();
      m_ops = ConferenceManagerOps.get(pool);

    } // end try
    catch (ConfigException e)
    { // convert it to a ModuleException
      throw new ModuleException(e);

    } // end catch

  } // end constructor

  /*--------------------------------------------------------------------------------
   * Implementations from interface DynamicObject
   *--------------------------------------------------------------------------------
   */

  public Object get(String property_name) throws DynamicObjectException
  {
    return m_dobj.get(property_name);

  } // end get

  public void set(String property_name, Object value) throws DynamicObjectException
  {
    m_dobj.set(property_name,value);

  } // end set

  public Object call(String method_name, Object[] parameters) throws DynamicObjectException
  {
    return m_dobj.call(method_name,parameters);

  } // end call

  public Object call(String method_name, List parameters) throws DynamicObjectException
  {
    return m_dobj.call(method_name,parameters);

  } // end call

  public DynamicClass getDClass()
  {
    return m_dobj.getDClass();

  } // end getDClass
  
  /*--------------------------------------------------------------------------------
   * Implementations from interface ConferenceAccessObject
   *--------------------------------------------------------------------------------
   */

  public List getConferences(VeniceCommunity comm) throws DatabaseException
  {
    return Collections.EMPTY_LIST;  // TEMP

  } // end getConferences

  public VeniceConference getConference(int confid) throws DatabaseException
  {
    return null;  // TEMP

  } // end getConference

  public VeniceConference getConference(String alias) throws DatabaseException
  {
    return null;  // TEMP

  } // end getConference

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public void dispose()
  {
    m_ops.dispose();
    m_ops = null;
    m_uc.decrementUseCount();
    m_uc = null;

  } // end dispose

} // end class ConferenceManager
